@@ -26,7 +26,7 @@ class StaticArg(TypedDict):
     option: Optional[str]
     short: Optional[str]
     orig_help: Optional[str]
-    default: str
+    default: Optional[Union[bool, str]]
     help: Optional[str]
     action: Optional[str]
     choices: Optional[List[str]]
@@ -151,7 +151,9 @@ class ArgparseArg:
             "option": self.arg.option,
             "short": self.arg.short,
             "orig_help": self.arg.help,
-            "default": str(self.default),
+            "default": str(self.default)
+            if self.default not in (False, None)
+            else self.default,
             "help": self.help,
             "action": str(self.action) if self.action else None,
             "choices": list(c.value if isinstance(c, Enum) else c for c in self.choices)
@@ -306,6 +308,8 @@ def format_table(data: List[Tuple[str, str]]) -> str:
 
 
 def format_arg_help(text: Optional[str], max_width: int = 70) -> str:
+    if not text:
+        return " "
     d = (text or "").strip()[:max_width]
     end = "." if "." in d or len(text or "") <= max_width else "..."
     return (d.rsplit(".", 1)[0] if "." in d else d) + end
